@@ -1,5 +1,5 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/*
  * xap_TableWidget.h
  * Copyright 2002, Joaquin Cuenca Abela
  *
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #ifndef ABI_TABLE_H
@@ -41,20 +41,19 @@ typedef struct _AbiTable
 	GtkButton button;
 
 	/*<private>*/
-	GtkStockItem stock_item;
-
 	GtkWidget* button_box;
-	GtkWidget* label;
 	GtkWidget* icon;
 
 	GtkWindow* window;
-	GtkVBox* window_vbox;
+	GtkBox* window_vbox;
 	GtkDrawingArea* area;
 	GtkLabel* window_label;
 	GSList* handlers;
-	
-	GdkGC* selected_gc;
-	
+
+	GtkStyleContext* style_context;
+
+	gint pos_x;
+	gint pos_y;
 	guint selected_rows;
 	guint selected_cols;
 
@@ -92,10 +91,6 @@ void	   abi_table_get_max_size   (const AbiTable* abi_table, guint* rows, guint*
 	/* Sets the labels */
 	void abi_table_set_labels(AbiTable* abi_table, const gchar * szTable, const gchar * szCancel);
 
-	/* Returns the label widget */
-
-	GtkWidget * abi_table_get_label(AbiTable* abi_table);
-
 	/* Sets the table icon to the gtk_image cast as GtkWidget */
 
 	void abi_table_set_icon(AbiTable* abi_table, GtkWidget* icon);
